@@ -2,7 +2,7 @@ package Glib::Install::Files;
 
 $self = {
           'deps' => [],
-          'inc' => ' -I. -I/usr/include/glib-2.0 -I/usr/lib64/glib-2.0/include -I/usr/include/sysprof-4 -pthread -I/usr/lib64/libffi/include  -DGPERL_DISABLE_THREADSAFE ',
+          'inc' => ' -I. -I/usr/include/glib-2.0 -I/usr/lib64/glib-2.0/include -I/usr/lib64/libffi/include  -DGPERL_DISABLE_THREADSAFE ',
           'libs' => '-lgobject-2.0 -lglib-2.0 ',
           'typemaps' => [
                           'typemap'
